pub struct NetHsmImage {
pub image: ImageName,
pub port: ExposedPort,
}Expand description
An image of NetHSM used to create a running container.
Fields
image: ImageNameImage name that is used to start the container.
port: ExposedPortExposed port which will be used for communication with the NetHSM.
Implementations
Sourceimpl NetHsmImage
impl NetHsmImage
Sourcepub async fn url(&self) -> TestResult<Url>
pub async fn url(&self) -> TestResult<Url>
Returns an base URL for the virtualized NetHSM.